==> aws-java-sdk-emr-1.10.60-sources.jar: com/amazonaws/services/elasticmapreduce/model/transform/InstanceGroupJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.elasticmapreduce.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * InstanceGroupMarshaller
 */
public class InstanceGroupJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a JSONWriter
     */
    public void marshall(InstanceGroup instanceGroup, JSONWriter jsonWriter) {
        if (instanceGroup == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonWriter.object();

            if (instanceGroup.getId() != null) {
                jsonWriter.key("Id").value(instanceGroup.getId());
            }

            if (instanceGroup.getName() != null) {
                jsonWriter.key("Name").value(instanceGroup.getName());
            }

            if (instanceGroup.getMarket() != null) {
                jsonWriter.key("Market").value(instanceGroup.getMarket());
            }

            if (instanceGroup.getInstanceGroupType() != null) {
                jsonWriter.key("InstanceGroupType").value(
                        instanceGroup.getInstanceGroupType());
            }

            if (instanceGroup.getBidPrice() != null) {
                jsonWriter.key("BidPrice").value(instanceGroup.getBidPrice());
            }

            if (instanceGroup.getInstanceType() != null) {
                jsonWriter.key("InstanceType").value(
                        instanceGroup.getInstanceType());
            }

            if (instanceGroup.getRequestedInstanceCount() != null) {
                jsonWriter.key("RequestedInstanceCount").value(
                        instanceGroup.getRequestedInstanceCount());
            }

            if (instanceGroup.getRunningInstanceCount() != null) {
                jsonWriter.key("RunningInstanceCount").value(
                        instanceGroup.getRunningInstanceCount());
            }

            if (instanceGroup.getStatus() != null) {
                jsonWriter.key("Status");
                InstanceGroupStatusJsonMarshaller.getInstance().marshall(
                        instanceGroup.getStatus(), jsonWriter);
            }

            com.amazonaws.internal.SdkInternalList<Configuration> configurationsList = (com.amazonaws.internal.SdkInternalList<Configuration>) instanceGroup
                    .getConfigurations();
            if (!configurationsList.isEmpty()
                    || !configurationsList.isAutoConstruct()) {
                jsonWriter.key("Configurations");
                jsonWriter.array();
                for (Configuration configurationsListValue : configurationsList) {
                    if (configurationsListValue != null) {

                        ConfigurationJsonMarshaller.getInstance().marshall(
                                configurationsListValue, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }

            com.amazonaws.internal.SdkInternalList<EbsBlockDevice> ebsBlockDevicesList = (com.amazonaws.internal.SdkInternalList<EbsBlockDevice>) instanceGroup
                    .getEbsBlockDevices();
            if (!ebsBlockDevicesList.isEmpty()
                    || !ebsBlockDevicesList.isAutoConstruct()) {
                jsonWriter.key("EbsBlockDevices");
                jsonWriter.array();
                for (EbsBlockDevice ebsBlockDevicesListValue : ebsBlockDevicesList) {
                    if (ebsBlockDevicesListValue != null) {

                        EbsBlockDeviceJsonMarshaller.getInstance().marshall(
                                ebsBlockDevicesListValue, jsonWriter);
                    }
                }
                jsonWriter.endArray();
            }

            if (instanceGroup.getEbsOptimized() != null) {
                jsonWriter.key("EbsOptimized").value(
                        instanceGroup.getEbsOptimized());
            }

            jsonWriter.endObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static InstanceGroupJsonMarshaller instance;

    public static InstanceGroupJsonMarshaller getInstance() {
        if (instance == null)
            instance = new InstanceGroupJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-emr-1.10.64-sources.jar: com/amazonaws/services/elasticmapreduce/model/transform/InstanceGroupJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.elasticmapreduce.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * InstanceGroupMarshaller
 */
public class InstanceGroupJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(InstanceGroup instanceGroup,
            SdkJsonGenerator jsonGenerator) {
        if (instanceGroup == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (instanceGroup.getId() != null) {
                jsonGenerator.writeFieldName("Id").writeValue(
                        instanceGroup.getId());
            }
            if (instanceGroup.getName() != null) {
                jsonGenerator.writeFieldName("Name").writeValue(
                        instanceGroup.getName());
            }
            if (instanceGroup.getMarket() != null) {
                jsonGenerator.writeFieldName("Market").writeValue(
                        instanceGroup.getMarket());
            }
            if (instanceGroup.getInstanceGroupType() != null) {
                jsonGenerator.writeFieldName("InstanceGroupType").writeValue(
                        instanceGroup.getInstanceGroupType());
            }
            if (instanceGroup.getBidPrice() != null) {
                jsonGenerator.writeFieldName("BidPrice").writeValue(
                        instanceGroup.getBidPrice());
            }
            if (instanceGroup.getInstanceType() != null) {
                jsonGenerator.writeFieldName("InstanceType").writeValue(
                        instanceGroup.getInstanceType());
            }
            if (instanceGroup.getRequestedInstanceCount() != null) {
                jsonGenerator.writeFieldName("RequestedInstanceCount")
                        .writeValue(instanceGroup.getRequestedInstanceCount());
            }
            if (instanceGroup.getRunningInstanceCount() != null) {
                jsonGenerator.writeFieldName("RunningInstanceCount")
                        .writeValue(instanceGroup.getRunningInstanceCount());
            }
            if (instanceGroup.getStatus() != null) {
                jsonGenerator.writeFieldName("Status");
                InstanceGroupStatusJsonMarshaller.getInstance().marshall(
                        instanceGroup.getStatus(), jsonGenerator);
            }

            com.amazonaws.internal.SdkInternalList<Configuration> configurationsList = (com.amazonaws.internal.SdkInternalList<Configuration>) instanceGroup
                    .getConfigurations();
            if (!configurationsList.isEmpty()
                    || !configurationsList.isAutoConstruct()) {
                jsonGenerator.writeFieldName("Configurations");
                jsonGenerator.writeStartArray();
                for (Configuration configurationsListValue : configurationsList) {
                    if (configurationsListValue != null) {

                        ConfigurationJsonMarshaller.getInstance().marshall(
                                configurationsListValue, jsonGenerator);
                    }
                }
                jsonGenerator.writeEndArray();
            }

            com.amazonaws.internal.SdkInternalList<EbsBlockDevice> ebsBlockDevicesList = (com.amazonaws.internal.SdkInternalList<EbsBlockDevice>) instanceGroup
                    .getEbsBlockDevices();
            if (!ebsBlockDevicesList.isEmpty()
                    || !ebsBlockDevicesList.isAutoConstruct()) {
                jsonGenerator.writeFieldName("EbsBlockDevices");
                jsonGenerator.writeStartArray();
                for (EbsBlockDevice ebsBlockDevicesListValue : ebsBlockDevicesList) {
                    if (ebsBlockDevicesListValue != null) {

                        EbsBlockDeviceJsonMarshaller.getInstance().marshall(
                                ebsBlockDevicesListValue, jsonGenerator);
                    }
                }
                jsonGenerator.writeEndArray();
            }
            if (instanceGroup.getEbsOptimized() != null) {
                jsonGenerator.writeFieldName("EbsOptimized").writeValue(
                        instanceGroup.getEbsOptimized());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static InstanceGroupJsonMarshaller instance;

    public static InstanceGroupJsonMarshaller getInstance() {
        if (instance == null)
            instance = new InstanceGroupJsonMarshaller();
        return instance;
    }

}
